Skip to contents

Reports, per quantile level, the component coefficients and the gate coefficients with standard errors, z- and p-values – the inference on how membership depends on the gating covariates (and, across the grid, on tau).

Usage

# S3 method for class 'mixqrgate'
summary(object, ...)

Arguments

object

A "mixqrgate" object.

...

Unused.

Value

An object of class "summary.mixqrgate".